ValueArrayAccess

Trait ValueArrayAccess 

pub trait ValueArrayAccess<I> {
    type Target: ?Sized;

    // Required method
    fn get_idx(&self, i: I) -> Option<&Self::Target>;
}
Access to a value as an array

Required Associated Types

type Target: ?Sized

The target for nested lookups

Required Methods

fn get_idx(&self, i: I) -> Option<&Self::Target>

Gets a ref to a value based on n index, returns None if the current Value isn’t an Array or doesn’t contain the index it was asked for.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<I, T> ValueArrayAccess<I> for T
where T: ValueAsArray, <T as ValueAsArray>::Array: Indexed<I>,